//
//  ChartViewController.m
//  iPhoneCharts
//
//  Copyright Advanced Software Engineering Ltd 2010.
//  All rights reserved.
//

#import "ChartViewController.h"
#include "democharts.h"
#include "chartdir.h"


@implementation ChartViewController
@synthesize label;
@synthesize image;
@synthesize currentDemo;


- (void)setDemo:(int)demoIndex chart:(int)chartIndex {
	
	currentDemo = demoIndex;
	currentChart = chartIndex;
	DemoChart &demoModule = demoCharts[demoIndex];
	   
	//Set the title
	NSString *demoTitle = [NSString stringWithUTF8String:demoModule.name];
	if ((chartIndex > 0) || (demoModule.noOfCharts > 1))
		demoTitle = [NSString stringWithFormat:@"%@ (%d)", demoTitle, chartIndex + 1]; 
	[self.label setText:demoTitle]; 
	
	//Execute the sample code for the chart
	const char *dummy = 0;
	BaseChart *c = demoModule.createChart(chartIndex, &dummy);

	//Output the chart and put it in the image view
	MemBlock m = c->makeChart(Chart::PNG);
	
	CGRect frame = [[UIScreen mainScreen] bounds];
	int margin = 5;
	double ratio = (frame.size.width - margin * 2 < c->getWidth()) ? c->getWidth() / (double)(frame.size.width - margin * 2) : 1;
	self.image.frame = CGRectMake(frame.origin.x + (frame.size.width - c->getWidth() / ratio) / 2, 
					 frame.origin.y + (frame.size.height - c->getHeight() / ratio) / 2,
					 c->getWidth() / ratio, c->getHeight() / ratio);
	
	self.image.image = [UIImage imageWithData:[NSData dataWithBytes:m.data length:m.len]];
	
	delete c;
}

- (void)viewDidLoad {
    [super viewDidLoad];

	//
	//Set up the forward and rewind buttons
	//
	
	NSMutableArray *buttons = [[[NSMutableArray alloc] initWithCapacity:3] autorelease];

	[buttons addObject:[[[UIBarButtonItem alloc]
						 initWithBarButtonSystemItem:UIBarButtonSystemItemRewind 
						 target:self action:@selector(rewindClicked:)] autorelease]];
	
	UIBarButtonItem *bi = [[[UIBarButtonItem alloc]
							initWithBarButtonSystemItem:UIBarButtonSystemItemFixedSpace 
							target:nil action:nil] autorelease];
	bi.width = 12.0f;
	[buttons addObject:bi];
	
	[buttons addObject:[[[UIBarButtonItem alloc] 
						 initWithBarButtonSystemItem:UIBarButtonSystemItemFastForward
						 target:self action:@selector(forwardClicked:)] autorelease]];
	
	UIToolbar *tools = [[[UIToolbar alloc] initWithFrame:CGRectMake(0.0f, 0.0f, 90.0f, 45.0f)] autorelease];
	[tools setItems:buttons animated:NO];

	self.navigationItem.rightBarButtonItem = [[[UIBarButtonItem alloc] initWithCustomView:tools] autorelease];
}

- (void)rewindClicked:(id)sender {
	
	//
	//Rewind button is pressed. Go up the sample chart list.
	//
	
	if (currentChart > 0) {
		[self setDemo:currentDemo chart:currentChart - 1];
	} else {
		for (int nextIndex = currentDemo - 1; nextIndex >= 0; --nextIndex) {
			if (demoCharts[nextIndex].noOfCharts > 0) {
				[self setDemo:nextIndex chart:demoCharts[nextIndex].noOfCharts - 1];
				break;
			}
		}
	}
}

- (void)forwardClicked:(id)sender {

	//
	//Forward button is pressed. Go down the sample chart list.
	//
	
	if (currentChart + 1 < demoCharts[currentDemo].noOfCharts) {
		[self setDemo:currentDemo chart:currentChart + 1];
	} else {
		for (int nextIndex = currentDemo + 1; demoCharts[nextIndex].name != 0; ++nextIndex) {
			if (demoCharts[nextIndex].noOfCharts > 0) {
				[self setDemo:nextIndex chart:0];
				break;
			}
		}
	}
}


- (void)didReceiveMemoryWarning {
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}


- (void)dealloc {
    [super dealloc];
}


@end
