//
//  RootViewController.m
//  iPhoneCharts
//
//  Copyright Advanced Software Engineering Ltd 2010.
//  All rights reserved.
//

#import "RootViewController.h"
#include "democharts.h"


@implementation RootViewController
@synthesize chartVC;


#pragma mark -
#pragma mark View lifecycle

- (void)viewDidLoad {
    [super viewDidLoad];

    self.title = @"ChartDirector Demo";
	
	//Change "current working directory" to the resources directory because the sample code loads
	//background images and icons from the "current working directory".
	[[NSFileManager defaultManager] changeCurrentDirectoryPath:[[NSBundle mainBundle] resourcePath]];
}

- (void)viewWillAppear:(BOOL)animated {
	[super viewWillAppear:animated];
	
	if (self.chartVC) {
		//Scroll to the currently selected sample chart
		NSUInteger indexArr[] = {0, static_cast<NSUInteger>(self.chartVC.currentDemo)};
		NSIndexPath *path = [NSIndexPath indexPathWithIndexes:indexArr length:2];
		[self.tableView selectRowAtIndexPath:path animated:false scrollPosition:UITableViewScrollPositionNone];
		[self.tableView scrollToRowAtIndexPath:path atScrollPosition:UITableViewScrollPositionNone animated:true];
	}
}


#pragma mark -
#pragma mark Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    
	return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
	
	int i;
	for (i = 0; demoCharts[i].name != 0; ++i);
    return i;
}

- (void)tableView:(UITableView *)tableView willDisplayCell:(UITableViewCell *)cell forRowAtIndexPath:(NSIndexPath *)indexPath {
	
	//Highlight the cell if it represents a section heading
	if (demoCharts[indexPath.row].noOfCharts == 0) {
		[cell setBackgroundColor:[UIColor colorWithRed:0 green:0 blue:0.5 alpha:1]] ;
	}
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
	//Get the cell. We cache the cells for the section heading and the sample chart entry using different id.
	NSString *reuseId = (demoCharts[indexPath.row].noOfCharts == 0) ? @"Title" : @"Demo";
	UITableViewCell* cell = [tableView dequeueReusableCellWithIdentifier:reuseId];
       
    if (cell == nil) {
		cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:reuseId] autorelease];
	}
	
	//Use a different text style for section heading
	if (demoCharts[indexPath.row].noOfCharts == 0) {
		[cell.textLabel setTextAlignment:(NSTextAlignment)NSTextAlignmentCenter];
		[cell.textLabel setTextColor:[UIColor colorWithRed:1 green:1 blue:1 alpha:1]];
	}
	
	//Generate the cell
	[cell.textLabel setText:[NSString stringWithUTF8String:demoCharts[indexPath.row].name]];
    return cell;
}


#pragma mark -
#pragma mark Table view delegate

- (NSIndexPath *)tableView:(UITableView *)tableView willSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
	//Section heading is not selectable
 	return (demoCharts[indexPath.row].noOfCharts != 0) ? indexPath : nil;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    
	if(self.chartVC == nil) {
		self.chartVC = [[[ChartViewController alloc] initWithNibName:@"ChartView" bundle:[NSBundle mainBundle]] autorelease];
        [self.chartVC view];
	}
	
	//Execute and display the sample chart
	[self.navigationController pushViewController:self.chartVC animated:YES];
	[self.chartVC setDemo:(int)indexPath.row chart:0];
}


#pragma mark -
#pragma mark Memory management

- (void)didReceiveMemoryWarning {
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Relinquish ownership any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
    // Relinquish ownership of anything that can be recreated in viewDidLoad or on demand.
    // For example: self.myOutlet = nil;
}


- (void)dealloc {
    [super dealloc];
}


@end

